@@ -1,8 +1,8 @@
 test_that("relational operators within tolerance", {
   x <- .5-.3
   y <- .3-.1
-  expect_that(x %==% y, testthat::equals(TRUE))
-  expect_that(x %!=% y, testthat::equals(FALSE))
+  expect_equal(x %==% y, TRUE)
+  expect_equal(x %!=% y, FALSE)
 
   set.seed(123L)
   a <- jitter(1:10, 1e-3)
@@ -13,8 +13,8 @@ test_that("relational operators within tolerance", {
   greater    <- a %>>% b
   equal      <- a %==% b
   notequal   <- a %!=% b
-  expect_that(less,     testthat::equals(!greater))
-  expect_that(notequal, testthat::equals(!equal))
+  expect_equal(less,     !greater)
+  expect_equal(notequal, !equal)
 
   a <- jitter(1:10, 1e-7)
   b <- jitter(1:10, 1e-7)
@@ -25,9 +25,9 @@ test_that("relational operators within tolerance", {
   equal      <- a %==% b
   notequal   <- a %!=% b
   ids <- c(5L,8L)
-  expect_that(less[ids],        testthat::equals(!greater[ids]))
-  expect_that(less[-ids],       testthat::equals(greater[-ids]))
-  expect_that(less.eq,          testthat::equals(!greater))
-  expect_that(all(!equal[ids]), testthat::equals(TRUE))
-  expect_that(all(equal[-ids]), testthat::equals(TRUE))
+  expect_equal(less[ids],        !greater[ids])
+  expect_equal(less[-ids],       greater[-ids])
+  expect_equal(less.eq,          !greater)
+  expect_equal(all(!equal[ids]), TRUE)
+  expect_equal(all(equal[-ids]), TRUE)
 })
